@@ -5,7 +5,7 @@ use elrond_wasm::{
     types::BoxedBytes,
 };
 
-// #[allow(dead_code)]
+#[allow(dead_code)]
 extern "C" {
     fn mBufferNew() -> i32;
     fn mBufferNewFromBytes(byte_ptr: *const u8, byte_len: i32) -> i32;
@@ -128,6 +128,7 @@ impl ManagedBufferApi for crate::VmApiImpl {
         }
     }
 
+    #[cfg(feature = "new-mbuffer-set-slice-impl")]
     #[inline]
     fn mb_set_slice(
         &self,
@@ -150,6 +151,46 @@ impl ManagedBufferApi for crate::VmApiImpl {
         }
     }
 
+    #[cfg(not(feature = "new-mbuffer-set-slice-impl"))]
+    #[inline]
+    fn mb_set_slice(
+        &self,
+        dest_handle: Handle,
+        starting_position: usize,
+        source_slice: &[u8],
+    ) -> Result<(), InvalidSliceError> {
+        let dest_buffer_len = self.mb_len(dest_handle);
+        let slice_len = source_slice.len();
+        if starting_position + slice_len > dest_buffer_len {
+            return Err(InvalidSliceError);
+        }
+
+        let part_after_handle = self.mb_new_empty();
+        let part_after_start = starting_position + slice_len;
+        let nr_leftover_bytes_after = dest_buffer_len - part_after_start;
+        if nr_leftover_bytes_after > 0 {
+            let copy_result = self.mb_copy_slice(
+                dest_handle,
+                part_after_start,
+                nr_leftover_bytes_after,
+                part_after_handle,
+            );
+            if copy_result.is_err() {
+                return copy_result;
+            }
+        }
+
+        let copy_result = self.mb_copy_slice(dest_handle, 0, starting_position, dest_handle);
+        if copy_result.is_err() {
+            return copy_result;
+        }
+
+        self.mb_append_bytes(dest_handle, source_slice);
+        self.mb_append(dest_handle, part_after_handle);
+
+        Ok(())
+    }
+
     #[inline]
     fn mb_set_random(&self, dest_handle: Handle, length: usize) {
         unsafe {
